@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "15.0.3+3" },
-            { "jdk", "15.0.3" },
-            { "release", "15.0.3" },
+            { "full", "23" },
+            { "jdk", "23" },
+            { "release", "23" },
         };
     }
 }
