@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "20.0.1+9" },
-            { "jdk", "20.0.1" },
-            { "release", "20.0.1" },
+            { "full", "23" },
+            { "jdk", "23" },
+            { "release", "23" },
         };
     }
 }
