@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,18 +66,19 @@ import java.util.ListResourceBundle;
 public class FormatData_ff_Latn_GM extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_TimePatterns = new String[] {
-               "h:mm:ss a zzzz",
-               "h:mm:ss a z",
-               "h:mm:ss a",
-               "h:mm a",
-            };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "h:mm:ss\u202fa zzzz",
+            "h:mm:ss\u202fa z",
+            "h:mm:ss\u202fa",
+            "h:mm\u202fa",
+        };
         final Object[][] data = new Object[][] {
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.TimePatterns", metaValue_TimePatterns },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
         };
         return data;
     }
