@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -212,7 +208,6 @@ public class LocaleNames_dz extends OpenListResourceBundle {
             { "IL", "\u0f68\u0f72\u0f66\u0f0b\u0f62\u0f0b\u0f61\u0f7a\u0f63" },
             { "IM", "\u0f68\u0f0b\u0f61\u0f74\u0f63\u0f0b \u0f68\u0f7c\u0f55\u0f0b \u0f58\u0f71\u0f53" },
             { "IN", "\u0f62\u0f92\u0fb1\u0f0b\u0f42\u0f62" },
-            { "IO", "\u0f56\u0fb2\u0f72\u0f0b\u0f4a\u0f72\u0f64\u0f0b\u0f62\u0f92\u0fb1\u0f0b\u0f42\u0f62\u0f0b\u0f42\u0fb1\u0f72\u0f0b\u0f62\u0f92\u0fb1\u0f0b\u0f58\u0f5a\u0f7c\u0f0b\u0f66\u0f0b\u0f41\u0f7c\u0f44\u0f66" },
             { "IQ", "\u0f68\u0f72\u0f0b\u0f62\u0f71\u0f40" },
             { "IR", "\u0f68\u0f72\u0f0b\u0f62\u0f71\u0f53" },
             { "IS", "\u0f68\u0f71\u0f60\u0f72\u0f66\u0f0b\u0f63\u0f7a\u0f53\u0f4c" },
