@@ -858,7 +858,7 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "new", "newari" },
             { "nia", "niha" },
             { "niu", "niu\u00e9en" },
-            { "njo", "Ao" },
+            { "njo", "ao" },
             { "nmg", "ngoumba" },
             { "nnh", "ngiemboon" },
             { "nog", "noga\u00ef" },
@@ -1304,7 +1304,6 @@ public class LocaleNames_fr extends OpenListResourceBundle {
             { "type.ca.japanese", "calendrier japonais" },
             { "type.cf.standard", "format de devise standard" },
             { "type.co.phonetic", "ordre de tri phon\u00e9tique" },
-            { "type.co.reformed", "ordre r\u00e9form\u00e9" },
             { "type.co.searchjl", "rechercher par consonne initiale en hangeul" },
             { "type.co.standard", "ordre de tri standard" },
             { "type.ms.uksystem", "syst\u00e8me imp\u00e9rial" },
