@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -112,11 +112,15 @@ public class TimeZoneNames_pt_ST extends TimeZoneNamesBundle {
             { "UTC", EMPTY_ZONE },
             { "ART", Europe_Eastern },
             { "ECT", Europe_Central },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Poland", Europe_Central },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
@@ -127,7 +131,6 @@ public class TimeZoneNames_pt_ST extends TimeZoneNamesBundle {
             { "Europe/Malta", Europe_Central },
             { "Europe/Sofia", Europe_Eastern },
             { "Europe/Vaduz", Europe_Central },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Lisbon", Europe_Western },
@@ -142,7 +145,9 @@ public class TimeZoneNames_pt_ST extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Tripoli", Europe_Eastern },
+            { "Atlantic/Faroe", Europe_Western },
             { "Europe/Andorra", Europe_Central },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
@@ -156,6 +161,7 @@ public class TimeZoneNames_pt_ST extends TimeZoneNamesBundle {
             { "Europe/Chisinau", Europe_Eastern },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "Atlantic/Madeira", Europe_Western },
             { "Europe/Amsterdam", Europe_Central },
