@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -68,11 +68,11 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "GMT (waxtu Greenwich)",
+               "GMT",
                "",
+               "BST",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] ETC_UTC = new String[] {
                "CUT (waxtu iniwelsel yu\u00f1 boole)",
@@ -84,67 +84,67 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "AST (waxtu est\u00e0ndaaru penku)",
-               "",
+               "AST",
                "ADT (waxtu b\u00ebcc\u00ebgu atl\u00e0ntik)",
-               "",
+               "AST",
                "AT (waxtu atl\u00e0ntik)",
-               "",
+               "AST",
             };
         final String[] Europe_Central = new String[] {
                "CEST (waxtu est\u00e0ndaaru \u00ebroop s\u00e0ntaraal)",
-               "",
+               "CET",
                "CEST (waxtu ete wu \u00ebroop s\u00e0ntaraal)",
-               "",
+               "CEST",
                "CTE (waxtu \u00ebroop s\u00e0ntaraal)",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "EEST (waxtu est\u00e0ndaaru \u00ebroop u penku)",
-               "",
+               "EET",
                "EEST (waxtu ete wu \u00ebroop u penku)",
-               "",
+               "EEST",
                "EET (waxtu \u00ebroop u penku)",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "WEST (waxtu est\u00e0ndaaru \u00ebroop u sowwu-jant)",
-               "",
+               "WET",
                "WEST (waxtu ete wu \u00ebroop u sowwu-jant)",
-               "",
+               "WEST",
                "WET (waxtu \u00ebroop u sowwu-jant",
-               "",
+               "WET",
             };
         final String[] America_Central = new String[] {
                "CST (waxtu est\u00e0ndaaru s\u00e0ntaraal)",
-               "",
+               "CST",
                "CDT (waxtu b\u00ebcc\u00ebgu s\u00e0ntaraal",
-               "",
+               "CDT",
                "CT (waxtu s\u00e0ntaral)",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "EST (waxtu est\u00e0ndaaru penku)",
-               "",
+               "EST",
                "EDT (waxtu b\u00ebcc\u00ebgu penku)",
-               "",
+               "EST",
                "ET waxtu penku",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "PST (waxtu est\u00e0ndaaru pasifik)",
-               "",
+               "PST",
                "PDT (waxtu b\u00ebcc\u00ebgu pasifik)",
-               "",
+               "PDT",
                "PT (waxtu pasifik)",
-               "",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
                "MST (waxtu est\u00e0ndaaru tundu)",
-               "",
+               "MST",
                "MDT (waxtu b\u00ebcc\u00ebgu tundu)",
-               "",
+               "MST",
                "MT (waxtu tundu)",
-               "",
+               "MST",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -158,27 +158,99 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
+            { "GB", GMT },
             { "ART", Europe_Eastern },
             { "CST", America_Central },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
             { "PNT", America_Mountain },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "UCT",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Eire", GMT },
+            { "GMT0", GMT },
+            { "Zulu",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire", GMT },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Universal",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -198,7 +270,17 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "CUT (waxtu iniwelsel yu\u00f1 boole)",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -221,17 +303,23 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast", GMT },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
+            { "Mexico/General", America_Central },
             { "Africa/Freetown", GMT },
             { "Africa/Monrovia", GMT },
             { "Africa/Sao_Tome", GMT },
@@ -243,16 +331,19 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
@@ -261,6 +352,7 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "Europe/Guernsey", GMT },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
@@ -268,9 +360,11 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "SystemV/MST7MDT", America_Mountain },
             { "SystemV/PST8PDT", America_Pacific },
             { "America/Anguilla", Atlantic },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Montreal", America_Eastern },
             { "America/Resolute", America_Central },
             { "America/Shiprock", America_Mountain },
@@ -286,7 +380,9 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -300,6 +396,7 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "Europe/Luxembourg", Europe_Central },
             { "Europe/San_Marino", Europe_Central },
             { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Ouagadougou", GMT },
             { "America/Costa_Rica", America_Central },
             { "America/Grand_Turk", America_Eastern },
@@ -309,7 +406,6 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -325,12 +421,15 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Thunder_Bay", America_Eastern },
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
             { "America/Blanc-Sablon", Atlantic },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
+            { "America/Santa_Isabel", America_Pacific },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -345,11 +444,12 @@ public class TimeZoneNames_wo extends TimeZoneNamesBundle {
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "D\u00ebkk bu\u00f1 xamul" },
-            { "timezone.excity.Africa/Dakar", "Dakar" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
